@@ -1,5 +1,4 @@
 use strict;
-use warnings;
 package Log::Dispatch::File::Stamped;
 
 use File::Basename        qw(fileparse);
@@ -7,82 +6,73 @@ use File::Spec::Functions qw(catfile);
 use POSIX                 qw(strftime);
 
 use vars qw(@ISA $VERSION);
-use Log::Dispatch::File 2.38;
+use Log::Dispatch::File;
 @ISA = qw(Log::Dispatch::File);
 
-$VERSION = '0.10_010';      # for PAUSE
-$VERSION = eval $VERSION;   # the real version (a string literal)
+$VERSION = '0.05';
 
-use Params::Validate qw(validate SCALAR);
-Params::Validate::validation_options( allow_extra => 1 );
-
-
-sub _basic_init
+sub new
 {
-    my $self = shift;
+    my $proto = shift;
+    my $class = ref $proto || $proto;
 
-    $self->SUPER::_basic_init(@_);
+    my %params = @_;
+    my $self = bless {}, $class;
 
-    my %p = validate(
-        @_,
-        {
-            stamp_fmt => {
-                type => SCALAR,
-                default => '%Y%m%d',
-            },
-        },
-    );
+    # stamp format
+    $self->{stamp_fmt} = delete $params{stamp_fmt} || '%Y%m%d';
+    
+    # only append mode is supported
+    $params{mode} = 'append';
 
-    $self->{stamp_fmt} = $p{stamp_fmt};
-
-    # cache of last timestamp used
-    $self->{_stamp} = '';
+    # base class initialization
+    $self->_basic_init(%params);
 
     # split pathname into path, basename, extension
-    @$self{qw(_name _path _ext)} = fileparse($self->{filename}, '\.[^.]+');
+    @$self{qw(_name _path _ext)} = fileparse($params{filename}, '\.[^.]+');
 
-    # stored in $self->{filename} (overwrites original); used by _open_file()
-    $self->_make_filename;
+    return $self;
 }
-
-sub _make_filename
-{
-    my $self = shift;
-
-    my $stamp = strftime($self->{stamp_fmt}, localtime);
-
-    # re-use last filename if the stamp has not changed
-    return $self->{filename} if $stamp eq $self->{_stamp};
-
-    # build the stamped file name
-    my $filename = join '-', $self->{_name}, $stamp;
-    $filename .= $self->{_ext} if $self->{_ext};
-    $self->{filename} = catfile($self->{_path}, $filename);
-}
-
 sub log_message
 {
     my $self = shift;
-
-    # check if the filename is the same as last time...
-    my $old_filename = $self->{filename};
-    $self->_make_filename;
-
-    # don't re-open if we use close-after-write - the superclass will do it
-    if (not $self->{close} and $old_filename ne $self->{filename})
-    {
-        $self->_open_file;
-    }
-
+    # might need to open a new file
+    $self->_make_handle();
+    # let the base class do the logging
     $self->SUPER::log_message(@_);
 }
+sub _make_stamp
+{
+    my $self = shift;
+    # make stamp string from current date and time
+    return strftime($self->{stamp_fmt}, localtime);
+}
+sub _make_handle
+{
+    my $self = shift;
+
+    # make stamp string from current date and time
+    my $stamp = $self->_make_stamp();
+
+    # if the stamp string has changed, need to open a new logfile
+    if (!$self->{stamp} || $stamp ne $self->{stamp}) {
+        # build the stamped file name
+        my $filename = join '-', $self->{_name}, $stamp;
+        $filename .= $self->{_ext} if $self->{_ext};
+        $filename  = catfile($self->{_path}, $filename);
+        # close previous open logfile
+        close $self->{fh} if $self->{fh};
+        # open new logfile
+        $self->SUPER::_make_handle(filename => $filename, mode => 'append');
+    }
+}
 
 1;
 __END__
 
 =head1 NAME
 
-Log::Dispatch::File::Stamped - Logging to date/time stamped files (UNAUTHORIZED RELEASE)
+Log::Dispatch::File::Stamped - Logging to date/time stamped files
 
 =head1 SYNOPSIS
 
@@ -100,7 +90,7 @@ Log::Dispatch::File::Stamped - Logging to date/time stamped files (UNAUTHORIZED
 =head1 DESCRIPTION
 
 This module subclasses Log::Dispatch::File for logging to date/time
-stamped files, respecting all its configuration options.
+stamped files.
 
 =head1 METHODS
 
@@ -123,11 +113,15 @@ timestamp is inserted before the extension. See examples below.
 
 The format of the timestamp string. This module uses POSIX::strftime to
 create the timestamp string from the current local date and time.
-Refer to your platform's C<strftime> documentation for the list of allowed
+Refer to your platform's strftime documentation for the list of allowed
 tokens.
 
 Defaults to '%Y%m%d'.
 
+=item -- mode ($)
+
+This parameter is ignored, and is forced to 'append'.
+
 =back
 
 =item log_message( message => $ )
@@ -182,8 +176,5 @@ Perl README file.
 Dave Rolsky, author of the Log::Dispatch suite and many other
 fine modules on CPAN.
 
-This module was rewritten to respect all present (and future) options to
-L<Log::Dispatch::File> by Karen Etheridge, <ether@cpan.org>.
-
 =cut
 
